package com.dgtly.system.mapper;

import com.dgtly.system.domain.SysMagnetLog;
import java.util.List;
import java.util.Map;

/**
 * 磁铁日志Mapper接口
 * 
 * @author dgtly
 * @date 2021-07-29
 */
public interface SysMagnetLogMapper 
{
    /**
     * 查询磁铁日志
     * 
     * @param id 磁铁日志ID
     * @return 磁铁日志
     */
    public SysMagnetLog selectSysMagnetLogById(Long id);

    /**
     * 查询磁铁日志列表
     * 
     * @param sysMagnetLog 磁铁日志
     * @return 磁铁日志集合
     */
    public List<SysMagnetLog> selectSysMagnetLogList(SysMagnetLog sysMagnetLog);

    /**
     * 新增磁铁日志
     * 
     * @param sysMagnetLog 磁铁日志
     * @return 结果
     */
    public int insertSysMagnetLog(SysMagnetLog sysMagnetLog);

    /**
     * 修改磁铁日志
     * 
     * @param sysMagnetLog 磁铁日志
     * @return 结果
     */
    public int updateSysMagnetLog(SysMagnetLog sysMagnetLog);

    /**
     * 删除磁铁日志
     * 
     * @param id 磁铁日志ID
     * @return 结果
     */
    public int deleteSysMagnetLogById(Long id);

    /**
     * 批量删除磁铁日志
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteSysMagnetLogByIds(String[] ids);

    /**
     * 根据用户id，移动端、电脑端，查询最近一点的埋点记录
     *
     * @param paramMap
     * @return 磁铁日志
     */
    public SysMagnetLog selectOneByCondition(Map<String,Object> paramMap);
}
